@@ -1,7 +1,7 @@
 """
 Type annotations for account service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_account/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_account/literals/)
 
 Usage::
 
@@ -142,6 +142,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
