@@ -1,7 +1,7 @@
 """
 Type annotations for account service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_account/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_account/type_defs/)
 
 Usage::
 
@@ -36,29 +36,58 @@ __all__ = (
 AlternateContactTypeDef = TypedDict(
     "AlternateContactTypeDef",
     {
-        "AlternateContactType": NotRequired[AlternateContactTypeType],
-        "EmailAddress": NotRequired[str],
-        "Name": NotRequired[str],
-        "PhoneNumber": NotRequired[str],
-        "Title": NotRequired[str],
+        "AlternateContactType": AlternateContactTypeType,
+        "EmailAddress": str,
+        "Name": str,
+        "PhoneNumber": str,
+        "Title": str,
     },
+    total=False,
 )
 
-DeleteAlternateContactRequestRequestTypeDef = TypedDict(
-    "DeleteAlternateContactRequestRequestTypeDef",
+_RequiredDeleteAlternateContactRequestRequestTypeDef = TypedDict(
+    "_RequiredDeleteAlternateContactRequestRequestTypeDef",
     {
         "AlternateContactType": AlternateContactTypeType,
-        "AccountId": NotRequired[str],
     },
 )
+_OptionalDeleteAlternateContactRequestRequestTypeDef = TypedDict(
+    "_OptionalDeleteAlternateContactRequestRequestTypeDef",
+    {
+        "AccountId": str,
+    },
+    total=False,
+)
 
-GetAlternateContactRequestRequestTypeDef = TypedDict(
-    "GetAlternateContactRequestRequestTypeDef",
+
+class DeleteAlternateContactRequestRequestTypeDef(
+    _RequiredDeleteAlternateContactRequestRequestTypeDef,
+    _OptionalDeleteAlternateContactRequestRequestTypeDef,
+):
+    pass
+
+
+_RequiredGetAlternateContactRequestRequestTypeDef = TypedDict(
+    "_RequiredGetAlternateContactRequestRequestTypeDef",
     {
         "AlternateContactType": AlternateContactTypeType,
-        "AccountId": NotRequired[str],
     },
 )
+_OptionalGetAlternateContactRequestRequestTypeDef = TypedDict(
+    "_OptionalGetAlternateContactRequestRequestTypeDef",
+    {
+        "AccountId": str,
+    },
+    total=False,
+)
+
+
+class GetAlternateContactRequestRequestTypeDef(
+    _RequiredGetAlternateContactRequestRequestTypeDef,
+    _OptionalGetAlternateContactRequestRequestTypeDef,
+):
+    pass
+
 
 GetAlternateContactResponseTypeDef = TypedDict(
     "GetAlternateContactResponseTypeDef",
@@ -68,17 +97,31 @@ GetAlternateContactResponseTypeDef = TypedDict(
     },
 )
 
-PutAlternateContactRequestRequestTypeDef = TypedDict(
-    "PutAlternateContactRequestRequestTypeDef",
+_RequiredPutAlternateContactRequestRequestTypeDef = TypedDict(
+    "_RequiredPutAlternateContactRequestRequestTypeDef",
     {
         "AlternateContactType": AlternateContactTypeType,
         "EmailAddress": str,
         "Name": str,
         "PhoneNumber": str,
         "Title": str,
-        "AccountId": NotRequired[str],
     },
 )
+_OptionalPutAlternateContactRequestRequestTypeDef = TypedDict(
+    "_OptionalPutAlternateContactRequestRequestTypeDef",
+    {
+        "AccountId": str,
+    },
+    total=False,
+)
+
+
+class PutAlternateContactRequestRequestTypeDef(
+    _RequiredPutAlternateContactRequestRequestTypeDef,
+    _OptionalPutAlternateContactRequestRequestTypeDef,
+):
+    pass
+
 
 ResponseMetadataTypeDef = TypedDict(
     "ResponseMetadataTypeDef",
